@@ -9,7 +9,7 @@
 from __future__ import absolute_import
 from __future__ import print_function
 
-string = "1.3.1.2"
+string = "1.4.2"
 
 if __name__ == "__main__":
     print(string)
